# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.20-v202406060201
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TreemapItemOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'AssetOutputV1',
        'display_scalars': 'list[ScalarValueOutputV1]',
        'is_leaf_asset': 'bool',
        'priority': 'int',
        'size': 'object',
        'uncertain': 'bool'
    }

    attribute_map = {
        'asset': 'asset',
        'display_scalars': 'displayScalars',
        'is_leaf_asset': 'isLeafAsset',
        'priority': 'priority',
        'size': 'size',
        'uncertain': 'uncertain'
    }

    def __init__(self, asset=None, display_scalars=None, is_leaf_asset=None, priority=None, size=None, uncertain=False):
        """
        TreemapItemOutputV1 - a model defined in Swagger
        """

        self._asset = None
        self._display_scalars = None
        self._is_leaf_asset = None
        self._priority = None
        self._size = None
        self._uncertain = None

        if asset is not None:
          self.asset = asset
        if display_scalars is not None:
          self.display_scalars = display_scalars
        if is_leaf_asset is not None:
          self.is_leaf_asset = is_leaf_asset
        if priority is not None:
          self.priority = priority
        if size is not None:
          self.size = size
        if uncertain is not None:
          self.uncertain = uncertain

    @property
    def asset(self):
        """
        Gets the asset of this TreemapItemOutputV1.

        :return: The asset of this TreemapItemOutputV1.
        :rtype: AssetOutputV1
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """
        Sets the asset of this TreemapItemOutputV1.

        :param asset: The asset of this TreemapItemOutputV1.
        :type: AssetOutputV1
        """

        self._asset = asset

    @property
    def display_scalars(self):
        """
        Gets the display_scalars of this TreemapItemOutputV1.
        The display scalars evaluated for this asset

        :return: The display_scalars of this TreemapItemOutputV1.
        :rtype: list[ScalarValueOutputV1]
        """
        return self._display_scalars

    @display_scalars.setter
    def display_scalars(self, display_scalars):
        """
        Sets the display_scalars of this TreemapItemOutputV1.
        The display scalars evaluated for this asset

        :param display_scalars: The display_scalars of this TreemapItemOutputV1.
        :type: list[ScalarValueOutputV1]
        """

        self._display_scalars = display_scalars

    @property
    def is_leaf_asset(self):
        """
        Gets the is_leaf_asset of this TreemapItemOutputV1.

        :return: The is_leaf_asset of this TreemapItemOutputV1.
        :rtype: bool
        """
        return self._is_leaf_asset

    @is_leaf_asset.setter
    def is_leaf_asset(self, is_leaf_asset):
        """
        Sets the is_leaf_asset of this TreemapItemOutputV1.

        :param is_leaf_asset: The is_leaf_asset of this TreemapItemOutputV1.
        :type: bool
        """

        self._is_leaf_asset = is_leaf_asset

    @property
    def priority(self):
        """
        Gets the priority of this TreemapItemOutputV1.
        The highest priority condition met by this asset or asset tree. The highest priority condition possible has a value of 0; when no conditions are met, -1 is returned.

        :return: The priority of this TreemapItemOutputV1.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this TreemapItemOutputV1.
        The highest priority condition met by this asset or asset tree. The highest priority condition possible has a value of 0; when no conditions are met, -1 is returned.

        :param priority: The priority of this TreemapItemOutputV1.
        :type: int
        """

        self._priority = priority

    @property
    def size(self):
        """
        Gets the size of this TreemapItemOutputV1.
        The relative size of this asset or asset tree

        :return: The size of this TreemapItemOutputV1.
        :rtype: object
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this TreemapItemOutputV1.
        The relative size of this asset or asset tree

        :param size: The size of this TreemapItemOutputV1.
        :type: object
        """

        self._size = size

    @property
    def uncertain(self):
        """
        Gets the uncertain of this TreemapItemOutputV1.
        True if this item's priority is uncertain

        :return: The uncertain of this TreemapItemOutputV1.
        :rtype: bool
        """
        return self._uncertain

    @uncertain.setter
    def uncertain(self, uncertain):
        """
        Sets the uncertain of this TreemapItemOutputV1.
        True if this item's priority is uncertain

        :param uncertain: The uncertain of this TreemapItemOutputV1.
        :type: bool
        """

        self._uncertain = uncertain

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TreemapItemOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.20-v202406060201
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class AssetTreeBatchInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'child_host_id': 'str',
        'disable_asset_tree_index_update_during_sync': 'bool',
        'parent_host_id': 'str',
        'relationships': 'list[AssetTreeSingleInputV1]'
    }

    attribute_map = {
        'child_host_id': 'childHostId',
        'disable_asset_tree_index_update_during_sync': 'disableAssetTreeIndexUpdateDuringSync',
        'parent_host_id': 'parentHostId',
        'relationships': 'relationships'
    }

    def __init__(self, child_host_id=None, disable_asset_tree_index_update_during_sync=False, parent_host_id=None, relationships=None):
        """
        AssetTreeBatchInputV1 - a model defined in Swagger
        """

        self._child_host_id = None
        self._disable_asset_tree_index_update_during_sync = None
        self._parent_host_id = None
        self._relationships = None

        if child_host_id is not None:
          self.child_host_id = child_host_id
        if disable_asset_tree_index_update_during_sync is not None:
          self.disable_asset_tree_index_update_during_sync = disable_asset_tree_index_update_during_sync
        if parent_host_id is not None:
          self.parent_host_id = parent_host_id
        if relationships is not None:
          self.relationships = relationships

    @property
    def child_host_id(self):
        """
        Gets the child_host_id of this AssetTreeBatchInputV1.
        The Seeq ID of the datasource host in which the children are located.

        :return: The child_host_id of this AssetTreeBatchInputV1.
        :rtype: str
        """
        return self._child_host_id

    @child_host_id.setter
    def child_host_id(self, child_host_id):
        """
        Sets the child_host_id of this AssetTreeBatchInputV1.
        The Seeq ID of the datasource host in which the children are located.

        :param child_host_id: The child_host_id of this AssetTreeBatchInputV1.
        :type: str
        """
        if child_host_id is None:
            raise ValueError("Invalid value for `child_host_id`, must not be `None`")

        self._child_host_id = child_host_id

    @property
    def disable_asset_tree_index_update_during_sync(self):
        """
        Gets the disable_asset_tree_index_update_during_sync of this AssetTreeBatchInputV1.
        Whether to keep asset tree search index up to date during the sync or not

        :return: The disable_asset_tree_index_update_during_sync of this AssetTreeBatchInputV1.
        :rtype: bool
        """
        return self._disable_asset_tree_index_update_during_sync

    @disable_asset_tree_index_update_during_sync.setter
    def disable_asset_tree_index_update_during_sync(self, disable_asset_tree_index_update_during_sync):
        """
        Sets the disable_asset_tree_index_update_during_sync of this AssetTreeBatchInputV1.
        Whether to keep asset tree search index up to date during the sync or not

        :param disable_asset_tree_index_update_during_sync: The disable_asset_tree_index_update_during_sync of this AssetTreeBatchInputV1.
        :type: bool
        """

        self._disable_asset_tree_index_update_during_sync = disable_asset_tree_index_update_during_sync

    @property
    def parent_host_id(self):
        """
        Gets the parent_host_id of this AssetTreeBatchInputV1.
        The Seeq ID of the datasource host in which the parents are located.

        :return: The parent_host_id of this AssetTreeBatchInputV1.
        :rtype: str
        """
        return self._parent_host_id

    @parent_host_id.setter
    def parent_host_id(self, parent_host_id):
        """
        Sets the parent_host_id of this AssetTreeBatchInputV1.
        The Seeq ID of the datasource host in which the parents are located.

        :param parent_host_id: The parent_host_id of this AssetTreeBatchInputV1.
        :type: str
        """
        if parent_host_id is None:
            raise ValueError("Invalid value for `parent_host_id`, must not be `None`")

        self._parent_host_id = parent_host_id

    @property
    def relationships(self):
        """
        Gets the relationships of this AssetTreeBatchInputV1.
        The list containing AssetTreeSingleInputV1s to create/update parent-child relationships with.

        :return: The relationships of this AssetTreeBatchInputV1.
        :rtype: list[AssetTreeSingleInputV1]
        """
        return self._relationships

    @relationships.setter
    def relationships(self, relationships):
        """
        Sets the relationships of this AssetTreeBatchInputV1.
        The list containing AssetTreeSingleInputV1s to create/update parent-child relationships with.

        :param relationships: The relationships of this AssetTreeBatchInputV1.
        :type: list[AssetTreeSingleInputV1]
        """

        self._relationships = relationships

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AssetTreeBatchInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.20-v202406060201
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class AclInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'disable_permission_inheritance': 'bool',
        'entries': 'list[AceInputV1]',
        'localize_inherited': 'bool',
        'preview': 'bool'
    }

    attribute_map = {
        'disable_permission_inheritance': 'disablePermissionInheritance',
        'entries': 'entries',
        'localize_inherited': 'localizeInherited',
        'preview': 'preview'
    }

    def __init__(self, disable_permission_inheritance=False, entries=None, localize_inherited=False, preview=False):
        """
        AclInputV1 - a model defined in Swagger
        """

        self._disable_permission_inheritance = None
        self._entries = None
        self._localize_inherited = None
        self._preview = None

        if disable_permission_inheritance is not None:
          self.disable_permission_inheritance = disable_permission_inheritance
        if entries is not None:
          self.entries = entries
        if localize_inherited is not None:
          self.localize_inherited = localize_inherited
        if preview is not None:
          self.preview = preview

    @property
    def disable_permission_inheritance(self):
        """
        Gets the disable_permission_inheritance of this AclInputV1.
        Whether permission inheritance for the item should be disabled (default is false)

        :return: The disable_permission_inheritance of this AclInputV1.
        :rtype: bool
        """
        return self._disable_permission_inheritance

    @disable_permission_inheritance.setter
    def disable_permission_inheritance(self, disable_permission_inheritance):
        """
        Sets the disable_permission_inheritance of this AclInputV1.
        Whether permission inheritance for the item should be disabled (default is false)

        :param disable_permission_inheritance: The disable_permission_inheritance of this AclInputV1.
        :type: bool
        """

        self._disable_permission_inheritance = disable_permission_inheritance

    @property
    def entries(self):
        """
        Gets the entries of this AclInputV1.
        List of access control entries to set. Entries will be flattened to a minimal set of entries

        :return: The entries of this AclInputV1.
        :rtype: list[AceInputV1]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """
        Sets the entries of this AclInputV1.
        List of access control entries to set. Entries will be flattened to a minimal set of entries

        :param entries: The entries of this AclInputV1.
        :type: list[AceInputV1]
        """

        self._entries = entries

    @property
    def localize_inherited(self):
        """
        Gets the localize_inherited of this AclInputV1.
        If true, any existing inherited access control entries should be merged into the supplied ACL (default is true). This enables changing permission inheritance without changing the access to the item (default is true).

        :return: The localize_inherited of this AclInputV1.
        :rtype: bool
        """
        return self._localize_inherited

    @localize_inherited.setter
    def localize_inherited(self, localize_inherited):
        """
        Sets the localize_inherited of this AclInputV1.
        If true, any existing inherited access control entries should be merged into the supplied ACL (default is true). This enables changing permission inheritance without changing the access to the item (default is true).

        :param localize_inherited: The localize_inherited of this AclInputV1.
        :type: bool
        """

        self._localize_inherited = localize_inherited

    @property
    def preview(self):
        """
        Gets the preview of this AclInputV1.
        If true, new acl entries will be generated and returned but those acl entries will not be persisted to the item. This is useful for previewing how an acl change will modify entries without persisting the change

        :return: The preview of this AclInputV1.
        :rtype: bool
        """
        return self._preview

    @preview.setter
    def preview(self, preview):
        """
        Sets the preview of this AclInputV1.
        If true, new acl entries will be generated and returned but those acl entries will not be persisted to the item. This is useful for previewing how an acl change will modify entries without persisting the change

        :param preview: The preview of this AclInputV1.
        :type: bool
        """

        self._preview = preview

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AclInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.20-v202406060201
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class DisplayTemplatesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def archive_display_template(self, **kwargs):
        """
        Archive a display template
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_display_template(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the display template to archive. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.archive_display_template_with_http_info(**kwargs)
        else:
            (data) = self.archive_display_template_with_http_info(**kwargs)
            return data

    def archive_display_template_with_http_info(self, **kwargs):
        """
        Archive a display template
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_display_template_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the display template to archive. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_display_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `archive_display_template`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/display-templates/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', None),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_display_template(self, **kwargs):
        """
        Create a new template item for a display
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_display_template(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DisplayTemplateInputV1 body: (required)
        :return: DisplayTemplateOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DisplayTemplateOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_display_template_with_http_info(**kwargs)
        else:
            (data) = self.create_display_template_with_http_info(**kwargs)
            return data

    def create_display_template_with_http_info(self, **kwargs):
        """
        Create a new template item for a display
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_display_template_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DisplayTemplateInputV1 body: (required)
        :return: DisplayTemplateOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DisplayTemplateOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_display_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_display_template`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/display-templates', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DisplayTemplateOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_display_template(self, **kwargs):
        """
        Get a display template item
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_display_template(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the display template (required)
        :return: DisplayTemplateOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DisplayTemplateOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_display_template_with_http_info(**kwargs)
        else:
            (data) = self.get_display_template_with_http_info(**kwargs)
            return data

    def get_display_template_with_http_info(self, **kwargs):
        """
        Get a display template item
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_display_template_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the display template (required)
        :return: DisplayTemplateOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DisplayTemplateOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_display_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_display_template`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/display-templates/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DisplayTemplateOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_display_templates(self, **kwargs):
        """
        Get a list of display template items
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_display_templates(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first display template item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of display template items that will be returned in this page of results
        :return: DisplayTemplateOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DisplayTemplateOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_display_templates_with_http_info(**kwargs)
        else:
            (data) = self.get_display_templates_with_http_info(**kwargs)
            return data

    def get_display_templates_with_http_info(self, **kwargs):
        """
        Get a list of display template items
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_display_templates_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first display template item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of display template items that will be returned in this page of results
        :return: DisplayTemplateOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DisplayTemplateOutputListV1
        """

        all_params = ['offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_display_templates" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/display-templates', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DisplayTemplateOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_template(self, **kwargs):
        """
        Update a template item for a display
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_template(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DisplayTemplateInputV1 body: (required)
        :param str id: The Seeq ID for the display template (required)
        :return: DisplayTemplateOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DisplayTemplateOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_template_with_http_info(**kwargs)
        else:
            (data) = self.update_template_with_http_info(**kwargs)
            return data

    def update_template_with_http_info(self, **kwargs):
        """
        Update a template item for a display
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_template_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DisplayTemplateInputV1 body: (required)
        :param str id: The Seeq ID for the display template (required)
        :return: DisplayTemplateOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DisplayTemplateOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_template`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_template`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/display-templates/{id}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DisplayTemplateOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.20-v202406060201
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FormulaRunInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end': 'str',
        'formula': 'str',
        'fragments': 'list[str]',
        'function': 'str',
        'limit': 'int',
        'offset': 'int',
        'parameters': 'list[str]',
        'reduce_formula': 'str',
        'root': 'str',
        'start': 'str',
        'time_format': 'str'
    }

    attribute_map = {
        'end': 'end',
        'formula': 'formula',
        'fragments': 'fragments',
        'function': 'function',
        'limit': 'limit',
        'offset': 'offset',
        'parameters': 'parameters',
        'reduce_formula': 'reduceFormula',
        'root': 'root',
        'start': 'start',
        'time_format': 'timeFormat'
    }

    def __init__(self, end=None, formula=None, fragments=None, function=None, limit=None, offset=None, parameters=None, reduce_formula=None, root=None, start=None, time_format=None):
        """
        FormulaRunInputV1 - a model defined in Swagger
        """

        self._end = None
        self._formula = None
        self._fragments = None
        self._function = None
        self._limit = None
        self._offset = None
        self._parameters = None
        self._reduce_formula = None
        self._root = None
        self._start = None
        self._time_format = None

        if end is not None:
          self.end = end
        if formula is not None:
          self.formula = formula
        if fragments is not None:
          self.fragments = fragments
        if function is not None:
          self.function = function
        if limit is not None:
          self.limit = limit
        if offset is not None:
          self.offset = offset
        if parameters is not None:
          self.parameters = parameters
        if reduce_formula is not None:
          self.reduce_formula = reduce_formula
        if root is not None:
          self.root = root
        if start is not None:
          self.start = start
        if time_format is not None:
          self.time_format = time_format

    @property
    def end(self):
        """
        Gets the end of this FormulaRunInputV1.
        A string representing the ending index of the data to be returned.             The contents and whether or not it is required depends on the series type. For time series: a ISO 8601             timestamp (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm). For numeric (non-time) keys: a double-precision             number, optionally including units. For example: \"2.5ft\" or \"10 °C\"

        :return: The end of this FormulaRunInputV1.
        :rtype: str
        """
        return self._end

    @end.setter
    def end(self, end):
        """
        Sets the end of this FormulaRunInputV1.
        A string representing the ending index of the data to be returned.             The contents and whether or not it is required depends on the series type. For time series: a ISO 8601             timestamp (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm). For numeric (non-time) keys: a double-precision             number, optionally including units. For example: \"2.5ft\" or \"10 °C\"

        :param end: The end of this FormulaRunInputV1.
        :type: str
        """

        self._end = end

    @property
    def formula(self):
        """
        Gets the formula of this FormulaRunInputV1.
        The formula to be applied. Length must not exceed 1M characters.

        :return: The formula of this FormulaRunInputV1.
        :rtype: str
        """
        return self._formula

    @formula.setter
    def formula(self, formula):
        """
        Sets the formula of this FormulaRunInputV1.
        The formula to be applied. Length must not exceed 1M characters.

        :param formula: The formula of this FormulaRunInputV1.
        :type: str
        """
        if formula is None:
            raise ValueError("Invalid value for `formula`, must not be `None`")

        self._formula = formula

    @property
    def fragments(self):
        """
        Gets the fragments of this FormulaRunInputV1.

        :return: The fragments of this FormulaRunInputV1.
        :rtype: list[str]
        """
        return self._fragments

    @fragments.setter
    def fragments(self, fragments):
        """
        Sets the fragments of this FormulaRunInputV1.

        :param fragments: The fragments of this FormulaRunInputV1.
        :type: list[str]
        """

        self._fragments = fragments

    @property
    def function(self):
        """
        Gets the function of this FormulaRunInputV1.
        The ID of a function item for calling formulas with unbound values

        :return: The function of this FormulaRunInputV1.
        :rtype: str
        """
        return self._function

    @function.setter
    def function(self, function):
        """
        Sets the function of this FormulaRunInputV1.
        The ID of a function item for calling formulas with unbound values

        :param function: The function of this FormulaRunInputV1.
        :type: str
        """

        self._function = function

    @property
    def limit(self):
        """
        Gets the limit of this FormulaRunInputV1.
        The pagination limit, the total number of collection items that will be returned              in this page of results. Defaults to 1000

        :return: The limit of this FormulaRunInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this FormulaRunInputV1.
        The pagination limit, the total number of collection items that will be returned              in this page of results. Defaults to 1000

        :param limit: The limit of this FormulaRunInputV1.
        :type: int
        """

        self._limit = limit

    @property
    def offset(self):
        """
        Gets the offset of this FormulaRunInputV1.
        The pagination offset, the index of the first collection item that             will be returned in this page of results. Defaults to 0

        :return: The offset of this FormulaRunInputV1.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """
        Sets the offset of this FormulaRunInputV1.
        The pagination offset, the index of the first collection item that             will be returned in this page of results. Defaults to 0

        :param offset: The offset of this FormulaRunInputV1.
        :type: int
        """

        self._offset = offset

    @property
    def parameters(self):
        """
        Gets the parameters of this FormulaRunInputV1.

        :return: The parameters of this FormulaRunInputV1.
        :rtype: list[str]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this FormulaRunInputV1.

        :param parameters: The parameters of this FormulaRunInputV1.
        :type: list[str]
        """
        if parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")

        self._parameters = parameters

    @property
    def reduce_formula(self):
        """
        Gets the reduce_formula of this FormulaRunInputV1.
        Used when running a formula across assets, this is a formula that can further reduce the              results of each asset result. The variable $result             must be used to reference the data. Example of sorting the aggregated results:             $result.sort('temperature')'

        :return: The reduce_formula of this FormulaRunInputV1.
        :rtype: str
        """
        return self._reduce_formula

    @reduce_formula.setter
    def reduce_formula(self, reduce_formula):
        """
        Sets the reduce_formula of this FormulaRunInputV1.
        Used when running a formula across assets, this is a formula that can further reduce the              results of each asset result. The variable $result             must be used to reference the data. Example of sorting the aggregated results:             $result.sort('temperature')'

        :param reduce_formula: The reduce_formula of this FormulaRunInputV1.
        :type: str
        """

        self._reduce_formula = reduce_formula

    @property
    def root(self):
        """
        Gets the root of this FormulaRunInputV1.
        Used to run a formula across assets, this is the ID of the root asset whose immediate             children will be iterated. The formula must produce a table.

        :return: The root of this FormulaRunInputV1.
        :rtype: str
        """
        return self._root

    @root.setter
    def root(self, root):
        """
        Sets the root of this FormulaRunInputV1.
        Used to run a formula across assets, this is the ID of the root asset whose immediate             children will be iterated. The formula must produce a table.

        :param root: The root of this FormulaRunInputV1.
        :type: str
        """

        self._root = root

    @property
    def start(self):
        """
        Gets the start of this FormulaRunInputV1.
        A string representing the starting index of the data to be returned.             The contents and whether or not it is required depends on the series type. For time series: a ISO 8601             timestamp (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm). For numeric (non-time) keys: a double-precision             number, optionally including units. For example: \"2.5ft\" or \"10 °C\"

        :return: The start of this FormulaRunInputV1.
        :rtype: str
        """
        return self._start

    @start.setter
    def start(self, start):
        """
        Sets the start of this FormulaRunInputV1.
        A string representing the starting index of the data to be returned.             The contents and whether or not it is required depends on the series type. For time series: a ISO 8601             timestamp (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm). For numeric (non-time) keys: a double-precision             number, optionally including units. For example: \"2.5ft\" or \"10 °C\"

        :param start: The start of this FormulaRunInputV1.
        :type: str
        """

        self._start = start

    @property
    def time_format(self):
        """
        Gets the time_format of this FormulaRunInputV1.
        The format to output time fields as. One of ISO8601, Nanoseconds, or Legacy, which          outputs whatever the default was before this field was added. Defaults to \"Legacy\".

        :return: The time_format of this FormulaRunInputV1.
        :rtype: str
        """
        return self._time_format

    @time_format.setter
    def time_format(self, time_format):
        """
        Sets the time_format of this FormulaRunInputV1.
        The format to output time fields as. One of ISO8601, Nanoseconds, or Legacy, which          outputs whatever the default was before this field was added. Defaults to \"Legacy\".

        :param time_format: The time_format of this FormulaRunInputV1.
        :type: str
        """
        allowed_values = ["Legacy", "ISO8601", "Nanoseconds"]
        if time_format not in allowed_values:
            raise ValueError(
                "Invalid value for `time_format` ({0}), must be one of {1}"
                .format(time_format, allowed_values)
            )

        self._time_format = time_format

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FormulaRunInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.20-v202406060201
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnDefinitionInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_name': 'str',
        'column_rules': 'list[ColumnRuleInputV1]',
        'column_type': 'str',
        'column_uom': 'str',
        'is_indexed': 'bool'
    }

    attribute_map = {
        'column_name': 'columnName',
        'column_rules': 'columnRules',
        'column_type': 'columnType',
        'column_uom': 'columnUom',
        'is_indexed': 'isIndexed'
    }

    def __init__(self, column_name=None, column_rules=None, column_type=None, column_uom=None, is_indexed=None):
        """
        ColumnDefinitionInputV1 - a model defined in Swagger
        """

        self._column_name = None
        self._column_rules = None
        self._column_type = None
        self._column_uom = None
        self._is_indexed = None

        if column_name is not None:
          self.column_name = column_name
        if column_rules is not None:
          self.column_rules = column_rules
        if column_type is not None:
          self.column_type = column_type
        if column_uom is not None:
          self.column_uom = column_uom
        if is_indexed is not None:
          self.is_indexed = is_indexed

    @property
    def column_name(self):
        """
        Gets the column_name of this ColumnDefinitionInputV1.
        Name of the column. This will be used as the header for this column. It must be unique for this table

        :return: The column_name of this ColumnDefinitionInputV1.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this ColumnDefinitionInputV1.
        Name of the column. This will be used as the header for this column. It must be unique for this table

        :param column_name: The column_name of this ColumnDefinitionInputV1.
        :type: str
        """
        if column_name is None:
            raise ValueError("Invalid value for `column_name`, must not be `None`")

        self._column_name = column_name

    @property
    def column_rules(self):
        """
        Gets the column_rules of this ColumnDefinitionInputV1.
        The list of rules that determine the resulting value of a column. At least one rule is required

        :return: The column_rules of this ColumnDefinitionInputV1.
        :rtype: list[ColumnRuleInputV1]
        """
        return self._column_rules

    @column_rules.setter
    def column_rules(self, column_rules):
        """
        Sets the column_rules of this ColumnDefinitionInputV1.
        The list of rules that determine the resulting value of a column. At least one rule is required

        :param column_rules: The column_rules of this ColumnDefinitionInputV1.
        :type: list[ColumnRuleInputV1]
        """
        if column_rules is None:
            raise ValueError("Invalid value for `column_rules`, must not be `None`")

        self._column_rules = column_rules

    @property
    def column_type(self):
        """
        Gets the column_type of this ColumnDefinitionInputV1.
        The type for the column

        :return: The column_type of this ColumnDefinitionInputV1.
        :rtype: str
        """
        return self._column_type

    @column_type.setter
    def column_type(self, column_type):
        """
        Sets the column_type of this ColumnDefinitionInputV1.
        The type for the column

        :param column_type: The column_type of this ColumnDefinitionInputV1.
        :type: str
        """
        if column_type is None:
            raise ValueError("Invalid value for `column_type`, must not be `None`")
        allowed_values = ["UUID", "TEXT", "NUMERIC", "TIMESTAMPTZ", "BOOLEAN"]
        if column_type not in allowed_values:
            raise ValueError(
                "Invalid value for `column_type` ({0}), must be one of {1}"
                .format(column_type, allowed_values)
            )

        self._column_type = column_type

    @property
    def column_uom(self):
        """
        Gets the column_uom of this ColumnDefinitionInputV1.
        The unit of measure for this column. This is only applicable to columns whose type                      is NUMERIC. If provided, this will enforce that data in this column must be in this unit. For                      example, if the user specifies Fahrenheit and the value comes in as Meters, the value will not be                      inserted. If not provided, values with different units will be allowed to be stored and an extra                       column will be added to the generated table for the UOM

        :return: The column_uom of this ColumnDefinitionInputV1.
        :rtype: str
        """
        return self._column_uom

    @column_uom.setter
    def column_uom(self, column_uom):
        """
        Sets the column_uom of this ColumnDefinitionInputV1.
        The unit of measure for this column. This is only applicable to columns whose type                      is NUMERIC. If provided, this will enforce that data in this column must be in this unit. For                      example, if the user specifies Fahrenheit and the value comes in as Meters, the value will not be                      inserted. If not provided, values with different units will be allowed to be stored and an extra                       column will be added to the generated table for the UOM

        :param column_uom: The column_uom of this ColumnDefinitionInputV1.
        :type: str
        """

        self._column_uom = column_uom

    @property
    def is_indexed(self):
        """
        Gets the is_indexed of this ColumnDefinitionInputV1.

        :return: The is_indexed of this ColumnDefinitionInputV1.
        :rtype: bool
        """
        return self._is_indexed

    @is_indexed.setter
    def is_indexed(self, is_indexed):
        """
        Sets the is_indexed of this ColumnDefinitionInputV1.

        :param is_indexed: The is_indexed of this ColumnDefinitionInputV1.
        :type: bool
        """

        self._is_indexed = is_indexed

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnDefinitionInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
